@@ -43,8 +43,8 @@
 #'
 #' @references \itemize{
 #'   \item Bates D, Kliegl R, Vasishth S, Baayen H. Parsimonious Mixed Models. arXiv:1506.04967, June 2015.
-#'   \item Barr DJ, Levy R, Scheepers C, Tily HJ. Random effects structure for confirmatory hypothesis testing: Keep it maximal. Journal of Memory and Language, 68(3):255–278, April 2013.
-#'   \item Matuschek H, Kliegl R, Vasishth S, Baayen H, Bates D. Balancing type I error and power in linear mixed models. Journal of Memory and Language, 94:305–315, 2017.
+#'   \item Barr DJ, Levy R, Scheepers C, Tily HJ. Random effects structure for confirmatory hypothesis testing: Keep it maximal. Journal of Memory and Language, 68(3):255-278, April 2013.
+#'   \item Matuschek H, Kliegl R, Vasishth S, Baayen H, Bates D. Balancing type I error and power in linear mixed models. Journal of Memory and Language, 94:305-315, 2017.
 #'   }
 #'
 #' @examples
@@ -110,7 +110,7 @@ is_singular.merMod <- function(x, tolerance = 1e-5, ...) {
 #' @importFrom lme4 VarCorr
 #' @export
 is_singular.glmmTMB <- function(x, tolerance = 1e-5, ...) {
-  vc <- collapse_cond(lme4::VarCorr(x))
+  vc <- .collapse_cond(lme4::VarCorr(x))
   any(sapply(vc, function(.x) any(abs(diag(.x)) < tolerance)))
 }
 
