@@ -15,13 +15,18 @@
 #'   to calculate the ICC for this group-level. Only applies if \code{ppd = TRUE}.
 #' @param typical Character vector, naming the function that will be used as
 #'   measure of central tendency for the ICC. The default is "mean". See
-#'   \link{typical_value} for options.
+#'   \code{\link[sjmisc]{typical_value}} for options.
 #' @param ppd Logical, if \code{TRUE}, variance decomposition is based on the
 #'   posterior predictive distribution, which is the correct way for Bayesian
-#'   non-Gaussian models.
+#'   non-Gaussian models. By default, \code{ppd} is set to \code{TRUE} for
+#'   non-Gaussian models.If \code{adjusted = TRUE} and \code{ppd = FALSE},
+#'   variance decomposition is approximated following the suggestion by
+#'   \cite{Nakagawa et al. 2017} (see 'Details'), however, this is currently
+#'   only implemented for Gaussian models.
 #' @param adjusted Logical, if \code{TRUE}, the adjusted (and
 #'   conditional) ICC is calculated, which reflects the uncertainty of all
-#'   random effects (see 'Details').
+#'   random effects (see 'Details'). For Bayesian models, if \code{ppd = TRUE},
+#'   \code{adjusted} will be ignored.
 #'
 #' @inheritParams hdi
 #'
@@ -33,7 +38,7 @@
 #'    is also  included as attribute.
 #'
 #' @references \itemize{
-#'    \item Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490–1528 (\doi{10.1177/0149206313478188})
+#'    \item Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490-1528 (\doi{10.1177/0149206313478188})
 #'    \item Goldstein H, Browne W, Rasbash J. 2010. Partitioning Variation in Multilevel Models. Understanding Statistics, 1:4, 223-231 (\doi{10.1207/S15328031US0104_02})
 #'    \item Grace-Martion K. The Intraclass Correlation Coefficient in Mixed Models, \href{http://www.theanalysisfactor.com/the-intraclass-correlation-coefficient-in-mixed-models/}{web}
 #'    \item Hox J. 2002. Multilevel analysis: techniques and applications. Mahwah, NJ: Erlbaum
@@ -71,12 +76,15 @@
 #'     \item Random-Intercept-Slope-correlation: rho.01
 #'   }
 #'
-#' @details The ICC is calculated by dividing the between-group-variance (random
+#' @details The "simple" ICC (with both \code{ppd} and \code{adjusted} set to
+#'    \code{FALSE}) is calculated by dividing the between-group-variance (random
 #'    intercept variance) by the total variance (i.e. sum of between-group-variance
 #'    and within-group (residual) variance). \cr \cr
 #'    The calculation of the ICC for generalized linear mixed models with binary outcome is based on
 #'    \cite{Wu et al. (2012)}. For other distributions (negative binomial, poisson, ...),
-#'    calculation is based on \cite{Nakagawa et al. 2017}.
+#'    calculation is based on \cite{Nakagawa et al. 2017}, \strong{however}, for
+#'    non-Gaussian models it is recommended to compute the adjusted ICC (with
+#'    \code{adjusted = TRUE}, see below).
 #'    \cr \cr
 #'    \strong{ICC for unconditional and conditional models}
 #'    \cr \cr
@@ -99,7 +107,7 @@
 #'    proportion of variances.
 #'    \cr \cr
 #'    To get a meaningful ICC also for models with random slopes, use \code{adjusted = TRUE}.
-#'    The adjusted ICC used the mean random effect variance, which is based
+#'    The adjusted ICC uses the mean random effect variance, which is based
 #'    on the random effect variances for each value of the random slope
 #'    (see \cite{Johnson et al. 2014}).
 #'    \cr \cr
@@ -109,7 +117,7 @@
 #'    nested structure of the model, or for models with multiple random effects,
 #'    \code{icc()} only reports the proportion of variance explained for each
 #'    grouping level. Use \code{adjusted = TRUE} to calculate the adjusted and
-#'    conditional ICC.
+#'    conditional ICC, which condition on \emph{all random effects}.
 #'    \cr \cr
 #'    \strong{Adjusted and conditional ICC}
 #'    \cr \cr
@@ -120,7 +128,8 @@
 #'    \cite{Nakagawa et al. 2017}). If random effects are not nested and not
 #'    cross-classified, the adjusted (\code{adjusted = TRUE}) and unadjusted
 #'    (\code{adjusted = FALSE}) ICC are identical. \code{adjust = TRUE} returns
-#'    a meaningful ICC for models with random slopes.
+#'    a meaningful ICC for models with random slopes. Furthermore, the adjusted
+#'    ICC is recommended for models with other distributions than Gaussian.
 #'    \cr \cr
 #'    \strong{ICC for specific group-levels}
 #'    \cr \cr
@@ -172,8 +181,6 @@
 #'
 #' sleepstudy$mygrp <- sample(1:45, size = 180, replace = TRUE)
 #' fit2 <- lmer(Reaction ~ Days + (1 | mygrp) + (1 | Subject), sleepstudy)
-#' icc(fit2)
-#' icc(fit2, adjusted = TRUE)
 #'
 #' icc1 <- icc(fit1)
 #' icc2 <- icc(fit2)
@@ -231,17 +238,17 @@ icc.merMod <- function(x, adjusted = FALSE, ...) {
     type <- "icc"
 
   # compute adjusted and conditional ICC
-  if (adjusted) return(r2_mixedmodel(x, type = type))
+  if (adjusted) return(r2_mixedmodel(x, type = type, obj.name = deparse(substitute(x))))
 
   # get family
-  fitfam <- model_family(x)
+  fitfam <- insight::model_info(x)
 
 
   # random effects variances
   # for details on tau and sigma, see
   # Aguinis H, Gottfredson RK, Culpepper SA2013. Best-Practice Recommendations
   # for Estimating Cross-Level Interaction Effects Using Multilevel Modeling.
-  # Journal of Management 39(6): 1490–1528. doi:10.1177/0149206313478188.
+  # Journal of Management 39(6): 1490-1528. doi:10.1177/0149206313478188.
   reva <- lme4::VarCorr(x)
 
   # retrieve only intercepts
@@ -255,10 +262,10 @@ icc.merMod <- function(x, adjusted = FALSE, ...) {
   tau.11 <- unlist(lapply(reva, function(x) diag(x)[-1]))
 
   # residual variances, i.e. within-cluster-variance
-  resid_var <- get_residual_variance(x, var.cor = reva, fitfam, type = "ICC")
+  resid.var <- .get_variance_residual(x, var.cor = reva, fitfam, name = "ICC")
 
   # total variance, sum of random intercept and residual variances
-  total_var <- sum(purrr::map_dbl(vars, ~ sum(.x)), resid_var)
+  total_var <- sum(purrr::map_dbl(vars, ~ sum(.x)), resid.var)
 
   # random intercept icc
   ri.icc <- tau.00 / total_var
@@ -308,14 +315,14 @@ icc.merMod <- function(x, adjusted = FALSE, ...) {
   # add attributes, for print method
   class(ri.icc) <- c("sj_icc_merMod", class(ri.icc))
   attr(ri.icc, "family") <- fitfam$family
-  attr(ri.icc, "link") <- fitfam$link.fun
+  attr(ri.icc, "link") <- fitfam$link_function
   attr(ri.icc, "formula") <- stats::formula(x)
   attr(ri.icc, "model") <- mt
   attr(ri.icc, "tau.00") <- tau.00
   attr(ri.icc, "tau.01") <- tau.01
   attr(ri.icc, "rho.01") <- rho.01
   attr(ri.icc, "tau.11") <- tau.11
-  attr(ri.icc, "sigma_2") <- resid_var
+  attr(ri.icc, "sigma_2") <- resid.var
   attr(ri.icc, "rnd.slope.model") <- any(has_rnd_slope)
 
 
@@ -330,13 +337,15 @@ icc.merMod <- function(x, adjusted = FALSE, ...) {
 
 
 #' @importFrom lme4 VarCorr fixef getME
-#' @importFrom glmmTMB VarCorr fixef getME
 #' @importFrom stats family formula
 #' @importFrom purrr map map_dbl map_lgl
 #' @rdname icc
 #' @export
 icc.glmmTMB <- function(x, adjusted = FALSE, ...) {
 
+  if (!requireNamespace("glmmTMB", quietly = TRUE))
+    stop("Package `glmmTMB` is needed for this function. Please install it first.", call. = FALSE)
+
   add.args <- lapply(match.call(expand.dots = F)$`...`, function(x) x)
 
   if (obj_has_name(add.args, "type"))
@@ -345,17 +354,17 @@ icc.glmmTMB <- function(x, adjusted = FALSE, ...) {
     type <- "icc"
 
   # compute adjusted and conditional ICC
-  if (adjusted) return(r2_mixedmodel(x, type = type))
+  if (adjusted) return(r2_mixedmodel(x, type = type, obj.name = deparse(substitute(x))))
 
   # get family
-  fitfam <- model_family(x)
+  fitfam <- insight::model_info(x)
 
 
   # random effects variances
   # for details on tau and sigma, see
   # Aguinis H, Gottfredson RK, Culpepper SA2013. Best-Practice Recommendations
   # for Estimating Cross-Level Interaction Effects Using Multilevel Modeling.
-  # Journal of Management 39(6): 1490–1528. doi:10.1177/0149206313478188.
+  # Journal of Management 39(6): 1490-1528. doi:10.1177/0149206313478188.
   reva <- glmmTMB::VarCorr(x)[[1]]
 
   # retrieve only intercepts
@@ -369,10 +378,10 @@ icc.glmmTMB <- function(x, adjusted = FALSE, ...) {
   tau.11 <- unlist(lapply(reva, function(x) diag(x)[-1]))
 
   # residual variances, i.e. within-cluster-variance
-  resid_var <- get_residual_variance(x, var.cor = reva, fitfam, type = "ICC")
+  resid.var <- .get_variance_residual(x, var.cor = reva, fitfam, name = "ICC")
 
   # total variance, sum of random intercept and residual variances
-  total_var <- sum(purrr::map_dbl(vars, ~ sum(.x)), resid_var)
+  total_var <- sum(purrr::map_dbl(vars, ~ sum(.x)), resid.var)
 
   # random intercept icc
   ri.icc <- tau.00 / total_var
@@ -419,14 +428,14 @@ icc.glmmTMB <- function(x, adjusted = FALSE, ...) {
   # add attributes, for print method
   class(ri.icc) <- c("sj_icc_merMod", class(ri.icc))
   attr(ri.icc, "family") <- fitfam$family
-  attr(ri.icc, "link") <- fitfam$link.fun
+  attr(ri.icc, "link") <- fitfam$link_function
   attr(ri.icc, "formula") <- stats::formula(x)
   attr(ri.icc, "model") <- mt
   attr(ri.icc, "tau.00") <- tau.00
   attr(ri.icc, "tau.01") <- tau.01
   attr(ri.icc, "rho.01") <- rho.01
   attr(ri.icc, "tau.11") <- tau.11
-  attr(ri.icc, "sigma_2") <- resid_var
+  attr(ri.icc, "sigma_2") <- resid.var
   attr(ri.icc, "rnd.slope.model") <- any(has_rnd_slope)
 
 
@@ -442,18 +451,24 @@ icc.glmmTMB <- function(x, adjusted = FALSE, ...) {
 
 #' @importFrom stats formula
 #' @importFrom purrr map map_dbl map_lgl
-#' @importFrom sjmisc row_sums is_empty
+#' @importFrom sjmisc row_sums is_empty typical_value
 #' @rdname icc
 #' @export
-icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = FALSE, ...) {
+icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = FALSE, adjusted = FALSE, ...) {
 
   if (!requireNamespace("rstanarm", quietly = TRUE))
     stop("Please install and load package `rstanarm` first.", call. = F)
 
   # get family
-  fitfam <- model_family(x)
+  fitfam <- insight::model_info(x)
   xdat <- as.data.frame(x)
 
+  if (missing(ppd) && missing(adjusted) && !fitfam$is_linear) {
+    #message("Variance decomposition is based on the posterior predictive distribution. Set `ppd = FALSE` to calculate \"classical\" ICC, and `adjusted = TRUE` for adjusted ICC.")
+    message("Variance decomposition for non-Gaussian models should be based on the posterior predictive distribution. To do this, set `ppd = TRUE`.")
+    ## TODO set ppd to FALSE by default later
+    # ppd <- TRUE
+  }
 
   if (ppd) {
 
@@ -466,18 +481,18 @@ icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     tau.00 <- apply(PPD_0, MARGIN = 1, FUN = stats::var)
 
     ri.icc <- tau.00 / total_var
-    resid_var <- total_var - tau.00
+    resid.var <- total_var - tau.00
 
     icc_ <- c(
-      1 - typical_value(ri.icc, fun = typical),
-      typical_value(tau.00, fun = typical),
-      typical_value(resid_var, fun = typical),
-      typical_value(total_var, fun = typical)
+      1 - sjmisc::typical_value(ri.icc, fun = typical),
+      sjmisc::typical_value(tau.00, fun = typical),
+      sjmisc::typical_value(resid.var, fun = typical),
+      sjmisc::typical_value(total_var, fun = typical)
     )
 
     attr(icc_, "hdi.icc") <- rev(1 - hdi(ri.icc, prob = prob))
     attr(icc_, "hdi.tau.00") <- hdi(tau.00, prob = prob)
-    attr(icc_, "hdi.resid") <- hdi(resid_var, prob = prob)
+    attr(icc_, "hdi.resid") <- hdi(resid.var, prob = prob)
     attr(icc_, "hdi.total") <- hdi(total_var, prob = prob)
     attr(icc_, "re.form") <- re.form
     attr(icc_, "ranef") <- x$ranef$group[1]
@@ -486,6 +501,9 @@ icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     names(icc_) <- c("icc", "tau.00", "resid.var", "total.var")
     class(icc_) <- c("icc_ppd", class(icc_))
 
+  } else if (adjusted) {
+    # compute adjusted and conditional ICC
+    return(r2_mixedmodel(x, type = "ICC", obj.name = deparse(substitute(x))))
   } else {
 
     # random intercept-variances, i.e.
@@ -516,12 +534,21 @@ icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     # get residual standard deviation sigma
     sig <- xdat[["sigma"]]
 
+    # set default, if no residual variance is available
+    if (is.null(sig)) {
+      if (fitfam$is_binomial)
+        sig <- sqrt((pi^2) / 3)
+      else
+        sig <- 1
+    }
+
     # residual variance
-    resid_var <- sig^2
+    resid.var <- sig^2
 
     # total variance, sum of random intercept and residual variances
     total_var <- sjmisc::row_sums(
-      cbind(tau.00, data.frame(resid_var)),
+      cbind(tau.00, data.frame(resid.var)),
+      n = 1,
       var = "total_var",
       append = FALSE
     )
@@ -545,8 +572,8 @@ icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
       tau01s <- grep("^Sigma\\[(.*):[^\\(\\)](.*),\\(Intercept\\)\\]", colnames(xdat))
       tau.01 <- xdat[, tau01s, drop = FALSE]
 
-      tau.00.sums <- sjmisc::row_sums(tau.00, var = "t0sums")$t0sums
-      tau.11.sums <- sjmisc::row_sums(tau.11, var = "t1sums")$t1sums
+      tau.00.sums <- sjmisc::row_sums(tau.00, var = "t0sums", n = 1)$t0sums
+      tau.11.sums <- sjmisc::row_sums(tau.11, var = "t1sums", n = 1)$t1sums
 
       # get slope-intercept-correlations
       rho.01 <- tau.01 / sqrt(tau.00.sums * tau.11.sums)
@@ -561,35 +588,36 @@ icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
       mt <- "Linear mixed model"
 
 
-    icc_ <- purrr::map_dbl(ri.icc, ~ typical_value(.x, fun = typical))
+    icc_ <- purrr::map_dbl(ri.icc, ~ sjmisc::typical_value(.x, fun = typical))
     attr(icc_, "hdi.icc") <- purrr::map(ri.icc, ~ hdi(.x, prob = prob))
 
     attr(icc_, "hdi.tau.00") <- purrr::map(tau.00, ~ hdi(.x, prob = prob))
-    tau.00 <- purrr::map_dbl(tau.00, ~ typical_value(.x, fun = typical))
+    tau.00 <- purrr::map_dbl(tau.00, ~ sjmisc::typical_value(.x, fun = typical))
 
-    attr(icc_, "hdi.sigma_2") <- hdi(resid_var, prob = prob)
-    resid_var <- typical_value(resid_var, fun = typical)
+    if (length(resid.var) > 10)
+      attr(icc_, "hdi.sigma_2") <- hdi(resid.var, prob = prob)
+    resid.var <- sjmisc::typical_value(resid.var, fun = typical)
 
     if (!is.null(tau.11)) {
       attr(icc_, "hdi.tau.11") <- purrr::map(tau.11, ~ hdi(.x, prob = prob))
-      tau.11 <- purrr::map_dbl(tau.11, ~ typical_value(.x, fun = typical))
+      tau.11 <- purrr::map_dbl(tau.11, ~ sjmisc::typical_value(.x, fun = typical))
     }
 
     if (!is.null(rho.01)) {
       attr(icc_, "hdi.rho.01") <- purrr::map(rho.01, ~ hdi(.x, prob = prob))
-      rho.01 <- purrr::map_dbl(rho.01, ~ typical_value(.x, fun = typical))
+      rho.01 <- purrr::map_dbl(rho.01, ~ sjmisc::typical_value(.x, fun = typical))
     }
 
     if (!is.null(tau.01)) {
       attr(icc_, "hdi.tau.01") <- purrr::map(tau.01, ~ hdi(.x, prob = prob))
-      tau.01 <- purrr::map_dbl(tau.01, ~ typical_value(.x, fun = typical))
+      tau.01 <- purrr::map_dbl(tau.01, ~ sjmisc::typical_value(.x, fun = typical))
     }
 
     attr(icc_, "tau.00") <- tau.00
     attr(icc_, "tau.01") <- tau.01
     attr(icc_, "rho.01") <- rho.01
     attr(icc_, "tau.11") <- tau.11
-    attr(icc_, "sigma_2") <- resid_var
+    attr(icc_, "sigma_2") <- resid.var
     attr(icc_, "rnd.slope.model") <- any(has_rnd_slope)
     attr(icc_, "model") <- mt
 
@@ -598,7 +626,7 @@ icc.stanreg <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
 
   # add attributes, for print method
   attr(icc_, "family") <- fitfam$family
-  attr(icc_, "link") <- fitfam$link.fun
+  attr(icc_, "link") <- fitfam$link_function
   attr(icc_, "formula") <- stats::formula(x)
   attr(icc_, "prob") <- prob
 
@@ -619,7 +647,14 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     stop("Please install and load package `brms` first.", call. = F)
 
   # get family
-  fitfam <- model_family(x)
+  fitfam <- insight::model_info(x)
+
+  if (missing(ppd) && !fitfam$is_linear) {
+    #message("Variance decomposition is based on the posterior predictive distribution. Set `ppd = FALSE` to calculate \"classical\" ICC, and `adjusted = TRUE` for adjusted ICC.")
+    message("Variance decomposition for non-Gaussian models should be based on the posterior predictive distribution. To do this, set `ppd = TRUE`.")
+    ## TODO set ppd to FALSE by default later
+    # ppd <- TRUE
+  }
 
 
   if (ppd) {
@@ -633,18 +668,18 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     tau.00 <- apply(PPD_0, MARGIN = 1, FUN = stats::var)
 
     ri.icc <- tau.00 / total_var
-    resid_var <- total_var - tau.00
+    resid.var <- total_var - tau.00
 
     icc_ <- c(
-      1 - typical_value(ri.icc, fun = typical),
-      typical_value(tau.00, fun = typical),
-      typical_value(resid_var, fun = typical),
-      typical_value(total_var, fun = typical)
+      1 - sjmisc::typical_value(ri.icc, fun = typical),
+      sjmisc::typical_value(tau.00, fun = typical),
+      sjmisc::typical_value(resid.var, fun = typical),
+      sjmisc::typical_value(total_var, fun = typical)
     )
 
     attr(icc_, "hdi.icc") <- rev(1 - hdi(ri.icc, prob = prob))
     attr(icc_, "hdi.tau.00") <- hdi(tau.00, prob = prob)
-    attr(icc_, "hdi.resid") <- hdi(resid_var, prob = prob)
+    attr(icc_, "hdi.resid") <- hdi(resid.var, prob = prob)
     attr(icc_, "hdi.total") <- hdi(total_var, prob = prob)
     attr(icc_, "prob") <- prob
     attr(icc_, "re.form") <- re.form
@@ -680,7 +715,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
 
     # set default, if no residual variance is available
     if (is.null(sig)) {
-      if (fitfam$is_bin)
+      if (fitfam$is_binomial)
         sig <- sqrt((pi^2) / 3)
       else
         sig <- 1
@@ -690,41 +725,41 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
     # residual variances, i.e.
     # within-cluster-variance (sigma^2)
 
-    resid_var <- sig^2
+    resid.var <- sig^2
 
 
     # total variance, sum of random intercept and residual variances
-    total_var <- apply(as.data.frame(vars), MARGIN = 1, FUN = sum) + resid_var
+    total_var <- apply(as.data.frame(vars), MARGIN = 1, FUN = sum) + resid.var
 
     # make sure residual variance has same length as other components
     # if not, just repeat the current value to match number of samples
-    if (length(resid_var) == 1) resid_var <- rep(resid_var, length(total_var))
+    if (length(resid.var) == 1) resid.var <- rep(resid.var, length(total_var))
 
     # random intercept icc
     ri.icc <- purrr::map(tau.00, ~ .x / total_var)
 
     # random slope-variances (tau 11)
-    tau.11 <- purrr::map_if(tau.11, is.null, ~ rep(NA, length(resid_var)))
+    tau.11 <- purrr::map_if(tau.11, is.null, ~ rep(NA, length(resid.var)))
 
     names(ri.icc) <- sprintf("icc_%s", names(ri.icc))
     names(tau.00) <- sprintf("tau.00_%s", names(tau.00))
     names(tau.11) <- sprintf("tau.11_%s", names(tau.11))
 
-    icc_ <- purrr::map_dbl(ri.icc, ~ typical_value(.x, fun = typical))
+    icc_ <- purrr::map_dbl(ri.icc, ~ sjmisc::typical_value(.x, fun = typical))
 
-    attr(icc_, "tau.00") <- purrr::map_dbl(tau.00, ~ typical_value(.x, fun = typical))
+    attr(icc_, "tau.00") <- purrr::map_dbl(tau.00, ~ sjmisc::typical_value(.x, fun = typical))
     attr(icc_, "hdi.icc") <- purrr::map(ri.icc, ~ hdi(.x, prob = prob))
     attr(icc_, "hdi.tau.00") <- purrr::map(tau.00, ~ hdi(.x, prob = prob))
 
-    attr(icc_, "sigma_2") <- typical_value(resid_var, fun = typical)
-    attr(icc_, "hdi.sigma_2") <- hdi(resid_var, prob = prob)
+    attr(icc_, "sigma_2") <- sjmisc::typical_value(resid.var, fun = typical)
+    attr(icc_, "hdi.sigma_2") <- hdi(resid.var, prob = prob)
 
     attr(icc_, "prob") <- prob
 
     check_tau <- purrr::map_lgl(tau.11, ~ sjmisc::all_na(.x))
     if (any(!check_tau)) {
       tau.11 <- tau.11[!check_tau]
-      attr(icc_, "tau.11") <- purrr::map_dbl(tau.11, ~ typical_value(.x, fun = typical))
+      attr(icc_, "tau.11") <- purrr::map_dbl(tau.11, ~ sjmisc::typical_value(.x, fun = typical))
       attr(icc_, "hdi.tau.11") <- purrr::map(tau.11, ~ hdi(.x, prob = prob))
     }
 
@@ -738,7 +773,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
 
 
   attr(icc_, "family") <- fitfam$family
-  attr(icc_, "link") <- fitfam$link.fun
+  attr(icc_, "link") <- fitfam$link_function
   attr(icc_, "formula") <- stats::formula(x)
   attr(icc_, "model") <- "Bayesian mixed model"
   attr(ri.icc, "rnd.slope.model") <- any(has_rnd_slope)
@@ -758,8 +793,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
 #'
 #' @param x Fitted mixed effects model (of class \code{merMod}, \code{glmmTMB},
 #'   \code{stanreg} or \code{brmsfit}). \code{get_re_var()} also accepts
-#'   an object of class \code{icc.lme4}, as returned by the
-#'   \code{\link{icc}} function.
+#'   an object returned by the \code{\link{icc}} function.
 #' @param comp Name of the variance component to be returned. See 'Details'.
 #' @param adjusted Logical, if \code{TRUE}, returns the variance of the fixed
 #'   and random effects as well as of the additive dispersion and
@@ -770,7 +804,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
 #'           \code{re_var()} returns all random effects variances.
 #'
 #' @references \itemize{
-#'    \item Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490–1528 (\doi{10.1177/0149206313478188})
+#'    \item Aguinis H, Gottfredson RK, Culpepper SA. 2013. Best-Practice Recommendations for Estimating Cross-Level Interaction Effects Using Multilevel Modeling. Journal of Management 39(6): 1490-1528 (\doi{10.1177/0149206313478188})
 #'    \item Johnson PC, O'Hara RB. 2014. Extension of Nakagawa & Schielzeth's R2GLMM to random slopes models. Methods Ecol Evol, 5: 944-946. (\doi{10.1111/2041-210X.12225})
 #'    \item Nakagawa S, Johnson P, Schielzeth H (2017) The coefficient of determination R2 and intra-class correlation coefficient from generalized linear mixed-effects models revisted and expanded. J. R. Soc. Interface 14. \doi{10.1098/rsif.2017.0213}
 #'  }
@@ -798,7 +832,7 @@ icc.brmsfit <- function(x, re.form = NULL, typical = "mean", prob = .89, ppd = F
 #'         and \cite{Nakagawa et al. 2017}):
 #'         \describe{
 #'          \item{\code{"fixed"}}{variance attributable to the fixed effects}
-#'          \item{\code{"random"}}{variance of random effects}
+#'          \item{\code{"random"}}{(mean) variance of random effects}
 #'          \item{\code{"dispersion"}}{variance due to additive dispersion}
 #'          \item{\code{"distribution"}}{distribution-specific variance}
 #'          \item{\code{"residual"}}{sum of dispersion and distribution}
@@ -829,7 +863,7 @@ re_var <- function(x, adjusted = FALSE) {
 
   if (adjusted) {
 
-    rv <- r2(x)
+    rv <- r2_mixedmodel(x)
 
     rv_ <- list(
       var.fixef = attr(rv, "var.fixef", exact = TRUE),
@@ -849,7 +883,7 @@ re_var <- function(x, adjusted = FALSE) {
     rv <- c("sigma_2", "tau.00", "tau.11", "tau.01", "rho.01")
 
     # compute icc
-    icc_ <- suppressMessages(icc(x))
+    icc_ <- suppressMessages(icc(x, ppd = FALSE))
 
     rv_ <- purrr::map(rv, ~ attr(icc_, .x, exact = TRUE))
     rn <- purrr::map2(1:length(rv_), rv, ~ sjmisc::trim(paste(names(rv_[[.x]]), .y, sep = "_")))
@@ -868,15 +902,15 @@ re_var <- function(x, adjusted = FALSE) {
 #' @export
 get_re_var <- function(x, comp = c("tau.00", "tau.01", "tau.11", "rho.01", "sigma_2")) {
   # check if we have a valid object
-  if (!inherits(x, "icc.lme4") && !is_merMod(x) && !inherits(x, c("glmmTMB", "brmsfit"))) {
-    stop("`x` must either be an object returned by the `icc` function, or a merMod-, glmmTMB- or brmsfit-object.", call. = F)
+  if (!inherits(x, c("sj_icc_merMod", "sj_icc_stanreg", "sj_icc_brms")) && !is_merMod(x) && !inherits(x, c("glmmTMB", "brmsfit"))) {
+    stop("`x` must either be an object returned by the `icc()` function, or a merMod-, glmmTMB- or brmsfit-object.", call. = F)
   }
 
   # check arguments
   comp <- match.arg(comp)
 
   # do we have a merMod object? If yes, get ICC and var components
-  if (is_merMod(x) || inherits(x, c("glmmTMB", "brmsfit"))) x <- suppressMessages(icc(x))
+  if (is_merMod(x) || inherits(x, c("glmmTMB", "brmsfit"))) x <- suppressMessages(icc(x, ppd = FALSE))
 
   # return results
   attr(x, comp, exact = TRUE)
