@@ -231,6 +231,7 @@ wtd_mean <- function(x, weights = NULL) {
 #' @importFrom stats weighted.mean
 #' @export
 wtd_mean.default <- function(x, weights = NULL) {
+  if (is.null(weights)) weights <- rep(1, length(x))
   stats::weighted.mean(x, w = weights, na.rm = TRUE)
 }
 
@@ -239,8 +240,9 @@ wtd_mean.default <- function(x, weights = NULL) {
 #' @importFrom dplyr select_if
 #' @export
 wtd_mean.data.frame <- function(x, weights = NULL) {
+  if (is.null(weights)) weights <- rep(1, length(x))
   dplyr::select_if(x, is.numeric) %>%
-    purrr::map_dbl(~ weighted.mean(.x, w))
+    purrr::map_dbl(~ weighted.mean(.x, w = weights))
 }
 
 
@@ -273,6 +275,7 @@ wtd_se.default <- function(x, weights = NULL) {
 }
 
 wtd_se_helper <- function(x, weights) {
+  if (is.null(weights)) weights <- rep(1, length(x))
   sqrt(wtd_var(x, weights) / length(stats::na.omit(x)))
 }
 
